@@ -877,6 +877,29 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
+    def DescribeBGPIPL7Rules(self, request):
+        """高防IP获取7层规则
+
+        :param request: Request instance for DescribeBGPIPL7Rules.
+        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBGPIPL7RulesRequest`
+        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeBGPIPL7RulesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeBGPIPL7Rules", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeBGPIPL7RulesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
     def DescribeBasicDeviceStatus(self, request):
         """获取基础防护攻击状态
 
@@ -992,31 +1015,6 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeBlackWhiteIpList(self, request):
-        """接口变更
-
-        获取DDoS防护的IP黑白名单
-
-        :param request: Request instance for DescribeBlackWhiteIpList.
-        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeBlackWhiteIpListRequest`
-        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeBlackWhiteIpListResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeBlackWhiteIpList", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeBlackWhiteIpListResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeCCLevelList(self, request):
         """获取边界防护CC防护等级列表
 
@@ -1569,31 +1567,6 @@ class AntiddosClient(AbstractClient):
                 raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
-    def DescribeListProtectThresholdConfig(self, request):
-        """接口变更
-
-        获取防护阈值配置列表，包括DDoS的AI、等级、CC阈值开关等
-
-        :param request: Request instance for DescribeListProtectThresholdConfig.
-        :type request: :class:`tencentcloud.antiddos.v20200309.models.DescribeListProtectThresholdConfigRequest`
-        :rtype: :class:`tencentcloud.antiddos.v20200309.models.DescribeListProtectThresholdConfigResponse`
-
-        """
-        try:
-            params = request._serialize()
-            headers = request.headers
-            body = self.call("DescribeListProtectThresholdConfig", params, headers=headers)
-            response = json.loads(body)
-            model = models.DescribeListProtectThresholdConfigResponse()
-            model._deserialize(response["Response"])
-            return model
-        except Exception as e:
-            if isinstance(e, TencentCloudSDKException):
-                raise
-            else:
-                raise TencentCloudSDKException(type(e).__name__, str(e))
-
-
     def DescribeListProtocolBlockConfig(self, request):
         """获取DDoS防护的协议封禁配置列表
 
@@ -2193,7 +2166,7 @@ class AntiddosClient(AbstractClient):
 
 
     def SwitchWaterPrintConfig(self, request):
-        """开启或关闭DDoS防护的水印防护配置
+        """开启或关闭DDoS防护的水印防护配置，此功能为付费增值服务，有需求请联系售后
 
         :param request: Request instance for SwitchWaterPrintConfig.
         :type request: :class:`tencentcloud.antiddos.v20200309.models.SwitchWaterPrintConfigRequest`
